@@ -18,6 +18,37 @@ class SlackAlerter(Alerter):
             blocks=self.__generate_blocks(context)
         )
 
+    def generate_custom_message(self, project_id, dag_id, message_title, message, title, emoji=':warning:'):
+        """
+        Builds a custom message dictionary to mimic the format of the default Airflow context dictionary.
+
+        Usage:
+        slack = SlackAlerter(channel='#airflow')
+
+        slack.alert(slack.generate_custom_message(project_id='some_project_id',
+                                                      dag_id='dag_id',
+                                                      message_title='some_message_title',
+                                                      message='message',
+                                                      title='some_title'))
+
+        :param project_id:
+        :param dag_id:
+        :param message_title:
+        :param message:
+        :param emoji:
+        :param title:
+        :return:
+        """
+        return {
+            'name': title,
+            'body': {
+                'DAG': dag_id,
+                'emoji': emoji,
+                message_title: message,
+                'project': project_id,
+            }
+        }
+
     def __message_title(self, context):
         return context.get('name', 'alert').upper()
 
@@ -25,8 +56,14 @@ class SlackAlerter(Alerter):
         if context.get('name', '') == 'failure':
             emoji = ':rotating_light:'
             title = '<{}|{}>'.format(context['body']['error']['log_url'], self.__message_title(context))
+        elif context.get('name', '') == 'success':
+            emoji = ':white_check_mark:'
+            title = self.__message_title(context)
         else:
-            emoji = ':warning:'
+            emoji = ':question:'
+            if context['body'] and context['body']['emoji']:
+                emoji = context['body']['emoji']
+
             title = self.__message_title(context)
 
         return {
@@ -61,9 +98,12 @@ class SlackAlerter(Alerter):
                 if engineer_handles:
                     items['Engineers'] = ', '.join(['<@{}>'.format(handle) for handle in engineer_handles])
 
-        else:
+        elif context['name'] == 'success':
             items = {key: context['body'][key] for key in context['body'].keys() if
                      key not in ['project', 'engineers', 'status']}
+        else:
+            items = {key: context['body'][key] for key in context['body'].keys() if
+                     key not in ['emoji', 'project']}
 
         return self.__generate_message_body(items)
 
@@ -90,4 +130,4 @@ class SlackAlerter(Alerter):
         if 'project' in context['body']:
             blocks.append(self.__message_footer(context))
 
-        return blocks;
\ No newline at end of file
+        return blocks
