@@ -51,17 +51,18 @@ class BigQueryJobTaskMetricOperator(EventEmittingOperator):
     @apply_defaults
     def __init__(
             self,
-            task_ids=None,
+            task_ids=[],
+            xcom_key='return_value',
             bigquery_conn_id='bigquery_default',
             *args, **kwargs):
         """
         :param task_ids: List of task_ids saying which tasks to sink their job_metrics for
+        :param xcom_key: XCOM key used to pull the bigquery job id from the specified tasks
         """
 
         super(BigQueryJobTaskMetricOperator, self).__init__(*args, **kwargs)
-        if task_ids is None:
-            task_ids = []
         self.task_ids = task_ids
+        self.xcom_key = xcom_key
         self.bigquery_conn_id = bigquery_conn_id
 
     def execute(self, context):
@@ -71,7 +72,7 @@ class BigQueryJobTaskMetricOperator(EventEmittingOperator):
         jobs = hook.get_service().jobs()
 
         for task_id in self.task_ids:
-            job_id = context['task_instance'].xcom_pull(task_ids=task_id)
+            job_id = context['task_instance'].xcom_pull(key=self.xcom_key, task_ids=task_id)
             if job_id:
                 job = jobs.get(
                     projectId=hook.project_id,
